@@ -68,7 +68,16 @@
 #' vari <- iris[,1:4]
 #' facto <- iris[,5]
 #' 
-#' cva.1=CVA(vari, groups=facto) 
+#' cva.1=CVA(vari, groups=facto)
+#' ## get the typicality probabilities and resulting classifications - tagging
+#' ## all specimens with a probability of < 0.01 as outliers (assigned to no class)
+#' typprobs <- typprobClass(cva.1$CVscores,groups=facto)
+#' print(typprobs)
+#' ## visualize the CV scores by their groups estimated from (cross-validated)
+#' ## typicality probabilities:
+#' require(car)
+#' scatterplot(cva.1$CVscores[,1],cva.1$CVscores[,2],groups=typprobs$groupaffinCV,
+#'                   smooth=FALSE,reg.line=FALSE)
 #' # plot the CVA
 #' plot(cva.1$CVscores, col=facto, pch=as.numeric(facto), typ="n",asp=1,
 #'    xlab=paste("1st canonical axis", paste(round(cva.1$Var[1,2],1),"%")),
@@ -138,7 +147,7 @@
 #' deformGrid3d(cvvis5,cvvisNeg5,ngrid = 0)
 #' }
 #' @export
-CVA <- function (dataarray, groups, weighting = TRUE, tolinv = 1e-10,plot = TRUE, rounds = 0, cv = FALSE,p.adjust.method= p.adjust.methods) 
+CVA <- function (dataarray, groups, weighting = TRUE, tolinv = 1e-10,plot = TRUE, rounds = 0, cv = FALSE,p.adjust.method= "none") 
 {
     groups <- factor(groups)
     lev <- levels(groups)
@@ -293,7 +302,7 @@ CVA <- function (dataarray, groups, weighting = TRUE, tolinv = 1e-10,plot = TRUE
                 )
     class(out) <- "CVA"
     if (!cv) {
-        cl <- classify(out)
+        cl <- classify(out,cv=FALSE)
         out$class <- cl$class
         out$posterior <- cl$posterior
     }
