@@ -10,10 +10,7 @@
     l <- dim(N)[2]
     Gmeans <- matrix(0, ng, l)
     for (i in 1:ng) {
-        if(gsizes[i] > 1)
-            Gmeans[i, ] <- apply(N[groups==lev[i], ,drop=F], 2, mean)
-        else
-            Gmeans[i, ] <- N[groups==lev[i], ,drop=F]
+        Gmeans[i, ] <- colMeans(N[groups==lev[i], ,drop=F])
     }
     if (weighting)
         wt <- gsizes
